@@ -36,14 +36,14 @@ Options:
 
 """
 
-__version__ = '0.0.18'
+__version__ = '0.0.19'
 
 
 from ConfigParser import NoSectionError, SafeConfigParser
 from contextlib import contextmanager
 from getpass import getpass, getuser
 from os import fdopen, makedirs, remove
-from os.path import abspath, exists, expanduser, join
+from os.path import exists, expanduser, join
 from sys import stderr, stdin, stdout
 from traceback import format_exc
 
@@ -90,10 +90,10 @@ class Client(object):
     )
     for k, v in self.config_defaults.items():
       self.config.setdefault(k, v)
-    self.config['folder'] = abspath(expanduser(join(
+    self.config['folder'] = join(
       self.config['root_folder'],
       self.config.get('folder', None) or self.config['default_folder'],
-    )))
+    )
     self.use_password = use_password
 
   @contextmanager
